@@ -1,6 +1,7 @@
 import asyncio
 import logging
-from typing import Awaitable, Callable, Iterable, Optional, TypeVar
+from collections.abc import Awaitable, Iterable
+from typing import Callable, TypeVar
 
 from aiohttp import web
 from aiohttp.typedefs import Middleware
@@ -14,17 +15,17 @@ from alxhttp.middleware.defaults import default_middleware
 class Server:
   def __init__(
     self,
-    middlewares: Optional[Iterable[Middleware]] = None,
-    logger: Optional[logging.Logger] = None,
+    middlewares: Iterable[Middleware] | None = None,
+    logger: logging.Logger | None = None,
   ):
     if middlewares is None:
       middlewares = default_middleware()
     if logger is None:
       logger = get_json_server_logger()
-    self.app = web.Application(middlewares=middlewares, logger=logger)
+    self.app: web.Application = web.Application(middlewares=middlewares, logger=logger)
     self.host: str
     self.port: int
-    self.shutdown_event = asyncio.Event()
+    self.shutdown_event: asyncio.Event = asyncio.Event()
 
   async def setup_ctx(self, app: web.Application):
     """
@@ -38,7 +39,7 @@ class Server:
 
     runner = web.AppRunner(self.app, debug=True, access_log_class=JSONAccessLogger)
     await runner.setup()
-    site = web.TCPSite(runner, host, port)
+    site: web.TCPSite = web.TCPSite(runner, host, port)
 
     await site.start()
 
