@@ -1,6 +1,6 @@
 import asyncio
 import json
-from typing import Any
+from typing import Any, override
 
 from aiohttp import StreamReader
 from aiohttp.base_protocol import BaseProtocol
@@ -20,13 +20,14 @@ class BytesStreamReader(StreamReader):
     if loop is None:
       loop = asyncio.get_running_loop()
     super().__init__(DummyBaseProtocol(loop), 2**16, loop=loop)
-    self._data = data
+    self._data: bytes = data
 
   # async def _wait_for_data(self, func_name: str):
   # def feed_eof(self):
   # def is_eof(self):
   # def at_eof(self):
 
+  @override
   async def read(self, n: int = -1) -> bytes:
     if not self._data:
       return b''
@@ -40,9 +41,11 @@ class BytesStreamReader(StreamReader):
 
     return chunk
 
+  @override
   async def readany(self) -> bytes:
     return await self.read()
 
+  @override
   async def readline(self) -> bytes:
     newline_pos = self._data.find(b'\n')
     if newline_pos == -1:
