@@ -1,4 +1,5 @@
 import types
+from typing import Any
 
 SAFE_PRIMITIVE_TYPES = {str, int, float, bool}
 
@@ -6,14 +7,14 @@ SAFE_PRIMITIVE_TYPES_OR_NONE = SAFE_PRIMITIVE_TYPES | {types.NoneType}
 
 
 class TSRaw:
-  def __init__(self, value):
-    self.value = value
+  def __init__(self, value: Any):
+    self.value: Any = value
 
 
 class TSEnum:
   def __init__(self, name: str, value: str):
-    self.name = name
-    self.value = value
+    self.name: str = name
+    self.value: str = value
 
 
 class TSUndefined:
